Crate libxch [] [src]

A library for exchanging paths

This library provides a simple utility to swap files and/or directory content of two paths. When possible, this is done in an atomic fashion, so that only the full changes are observable.

Currently, atomic exchange is only supported on Windows and Linux.

Structs

Error

The Error type.

Enums

ErrorKind

The kind of an error.

Functions

xch

Exchange the content of the objects pointed to by the two paths.

xch_non_atomic

Exchange the content of the object pointed to by the two paths.